==> apache-camel-quarkus-3.8.1-src.zip: camel-quarkus-3.8.1/extensions/camel-k/runtime/src/main/java/org/apache/camel/quarkus/k/runtime/ApplicationRoutesConfig.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.k.runtime;

import java.util.List;
import java.util.Optional;

import io.smallrye.config.ConfigMapping;

@ConfigMapping(prefix = "camel.k.routes")
public interface ApplicationRoutesConfig {
    /**
     * A list of {@link RouteOverride} items to override some aspect of a {@link org.apache.camel.model.RouteDefinition}.
     */
    Optional<List<RouteOverride>> overrides();

    interface RouteOverride {
        /**
         * Identifies the route to be amended.
         */
        Optional<String> id();

        /**
         * Override for the {@link org.apache.camel.model.FromDefinition} of a {@link org.apache.camel.model.RouteDefinition}.
         */
        RouteInputOverride input();
    }

    interface RouteInputOverride {
        /**
         * The optional endpoint that should be replaced.
         */
        Optional<String> from();

        /**
         * The value that should replace the endpoint.
         */
        String with();
    }
}

==> apache-camel-quarkus-3.10.0-src.zip: camel-quarkus-3.10.0/extensions/camel-k/runtime/src/main/java/org/apache/camel/quarkus/k/runtime/ApplicationRoutesConfig.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.k.runtime;

import java.util.List;
import java.util.Optional;

import io.quarkus.runtime.annotations.ConfigPhase;
import io.quarkus.runtime.annotations.ConfigRoot;
import io.smallrye.config.ConfigMapping;

@ConfigMapping(prefix = "camel.k.routes")
@ConfigRoot(phase = ConfigPhase.RUN_TIME)
public interface ApplicationRoutesConfig {
    /**
     * A list of {@link RouteOverride} items to override some aspect of a {@link org.apache.camel.model.RouteDefinition}.
     */
    Optional<List<RouteOverride>> overrides();

    interface RouteOverride {
        /**
         * Identifies the route to be amended.
         */
        Optional<String> id();

        /**
         * Override for the {@link org.apache.camel.model.FromDefinition} of a
         * {@link org.apache.camel.model.RouteDefinition}.
         */
        RouteInputOverride input();
    }

    interface RouteInputOverride {
        /**
         * The optional endpoint that should be replaced.
         */
        Optional<String> from();

        /**
         * The value that should replace the endpoint.
         */
        String with();
    }
}
